@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminState.pm - to add/update/delete state
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminState.pm,v 1.38 2010/11/13 00:51:39 en Exp $
+# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +15,6 @@ use warnings;
 use Kernel::System::State;
 use Kernel::System::Valid;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.38 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -47,7 +42,9 @@ sub Run {
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Change' ) {
         my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
-        my %Data = $Self->{StateObject}->StateGet( ID => $ID, );
+        my %Data = $Self->{StateObject}->StateGet(
+            ID => $ID,
+        );
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
@@ -91,15 +88,12 @@ sub Run {
                 UserID => $Self->{UserID},
             );
 
-            # update not successful, show the edit screen again
-            if ( !$UpdateSuccess ) {
+            # update was successful
+            if ($UpdateSuccess) {
+                $Self->_Overview();
                 my $Output = $Self->{LayoutObject}->Header();
                 $Output .= $Self->{LayoutObject}->NavigationBar();
-                $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-                $Self->_Edit(
-                    Action => 'Change',
-                    %GetParam,
-                );
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'State updated!' );
                 $Output .= $Self->{LayoutObject}->Output(
                     TemplateFile => 'AdminState',
                     Data         => \%Param,
@@ -107,23 +101,12 @@ sub Run {
                 $Output .= $Self->{LayoutObject}->Footer();
                 return $Output;
             }
-
-            # update was successful
-            $Self->_Overview();
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Info => 'State updated!' );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminState',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
         }
 
-        # someting has gone wrong
+        # something has gone wrong
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
         $Self->_Edit(
             Action => 'Change',
             Errors => \%Errors,
@@ -185,14 +168,11 @@ sub Run {
                 %GetParam,
                 UserID => $Self->{UserID},
             );
-            if ( !$StateID ) {
+            if ($StateID) {
+                $Self->_Overview();
                 my $Output = $Self->{LayoutObject}->Header();
                 $Output .= $Self->{LayoutObject}->NavigationBar();
-                $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
-                $Self->_Edit(
-                    Action => 'Add',
-                    %GetParam,
-                );
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'State added!' );
                 $Output .= $Self->{LayoutObject}->Output(
                     TemplateFile => 'AdminState',
                     Data         => \%Param,
@@ -200,21 +180,12 @@ sub Run {
                 $Output .= $Self->{LayoutObject}->Footer();
                 return $Output;
             }
-            $Self->_Overview();
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
-            $Output .= $Self->{LayoutObject}->Notify( Info => 'State added!' );
-            $Output .= $Self->{LayoutObject}->Output(
-                TemplateFile => 'AdminState',
-                Data         => \%Param,
-            );
-            $Output .= $Self->{LayoutObject}->Footer();
-            return $Output;
         }
 
-        # someting has gone wrong
+        # something has gone wrong
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
         $Self->_Edit(
             Action => 'Add',
             Errors => \%Errors,
@@ -264,13 +235,13 @@ sub _Edit {
         Data       => \%ValidList,
         Name       => 'ValidID',
         SelectedID => $Param{ValidID} || $ValidListReverse{valid},
-        Class      => 'Validate_RequiredDropdown ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
     );
     $Param{StateTypeOption} = $Self->{LayoutObject}->BuildSelection(
-        Data => { $Self->{StateObject}->StateTypeList( UserID => 1 ), },
-        Name => 'TypeID',
+        Data       => { $Self->{StateObject}->StateTypeList( UserID => 1 ), },
+        Name       => 'TypeID',
         SelectedID => $Param{TypeID},
-        Class => 'Validate_RequiredDropdown ' . ( $Param{Errors}->{'TypeIDInvalid'} || '' ),
+        Class => 'Validate_Required ' . ( $Param{Errors}->{'TypeIDInvalid'} || '' ),
     );
     $Self->{LayoutObject}->Block(
         Name => 'OverviewUpdate',
