@@ -1,6 +1,6 @@
 // --
 // Core.Agent.Login.js - provides the special module functions for the login
-// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+// Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -26,7 +26,7 @@ Core.Agent.Login = (function (TargetNS) {
      */
     TargetNS.Init = function (LoginFailed) {
         // Browser is too old
-        if (!Core.Debug.BrowserCheckAgent()) {
+        if (!Core.Agent.SupportedBrowser) {
             $('#LoginBox').hide();
             $('#OldBrowser').show();
             return;
@@ -52,10 +52,15 @@ Core.Agent.Login = (function (TargetNS) {
         // save TimeOffset data for OTRS
         $('#TimeOffset').val((new Date()).getTimezoneOffset());
 
-        // shake login box on autentification failed
+        // shake login box on authentication failure
         if (LoginFailed) {
             Core.UI.Shake($('#LoginBox'));
         }
+
+        // if in PreLogin mode, automatically submit form
+        if ( $('#LoginBox').hasClass('PreLogin') ) {
+            $('#LoginBox form').submit();
+        }
     };
 
     return TargetNS;
