@@ -1,8 +1,6 @@
 // --
 // Core.JavaScriptEnhancements.UnitTest.js - UnitTests
-// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/\n";
-// --
-// $Id: Core.JavaScriptEnhancements.UnitTest.js,v 1.3 2012/12/11 09:05:42 mn Exp $
+// Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -11,7 +9,7 @@
 
 "use strict";
 
-var OTRS = OTRS || {};
+var Core = Core || {};
 
 Core.JavaScriptEnhancements = {};
 Core.JavaScriptEnhancements.RunUnitTests = function(){
@@ -28,4 +26,4 @@ Core.JavaScriptEnhancements.RunUnitTests = function(){
         equal(isJQueryObject($([]), $([])), true, 'multiple');
         equal(isJQueryObject($([]), $([]), {}), false, 'multiple, one plain object');
     });
-};
\ No newline at end of file
+};
